.. _papers:

Papers
------

The following papers use **PyAutoLens**:

**2019:**

`Galaxy structure with strong gravitational lensing: decomposing the internal mass distribution of massive elliptical galaxies <https://arxiv.org/abs/1901.07801>`_

`Likelihood-free MCMC with Amortized Approximate Likelihood Ratios <https://arxiv.org/abs/1903.04057>`_

`Deep Learning the Morphology of Dark Matter Substructure <https://arxiv.org/abs/1909.07346>`_

`The molecular-gas properties in the gravitationally lensed merger HATLAS J142935.3-002836 <https://arxiv.org/abs/1904.00307>`_

`Novel Substructure & Superfluid Dark Matter <https://arxiv.org/abs/1901.03694>`_

`CO, H2O, H2O+ line & dust emission in a z = 3.63 strongly lensed starburst merger at sub-kiloparsec scales <https://arxiv.org/abs/1903.00273>`_

`Subaru FOCAS IFU observations of two z=0.12 strong-lensing elliptical galaxies from SDSS MaNGA <https://arxiv.org/abs/1911.06338>`_

`Dark disk substructure and superfluid dark matter <https://arxiv.org/abs/1901.03694>`_

**2020:**

`Auto-identification of unphysical source reconstructions in strong gravitational lens modelling <https://arxiv.org/abs/2012.04665>`_

`ALMA [{N} {II}] 205 μm Imaging Spectroscopy of the Lensed Submillimeter Galaxy ID 141 at Redshift 4.24 <https://arxiv.org/abs/2006.01147>`_

`MNELLS: The MUSE Nearby Early-Type Galaxy Lens Locator Survey <https://arxiv.org/abs/2002.07191>`_

`Decoding Dark Matter Substructure without Supervision <https://arxiv.org/abs/2008.12731>`_


**2021:**

`A forward-modelling method to infer the dark matter particle mass from strong gravitational lenses  <https://arxiv.org/abs/2010.13221>`_

`Galaxy-galaxy strong lens perturbations: line-of-sight haloes versus lens subhaloes <https://arxiv.org/abs/2110.04512>`_

`Systematic Errors Induced by the Elliptical Power-law model in Galaxy–Galaxy Strong Lens Modeling <https://arxiv.org/abs/2110.14554>`_

`Halo concentration strengthens dark matter constraints in galaxy–galaxy strong lensing analyses <https://arxiv.org/abs/2109.00018>`_

`Strong lens modelling: comparing and combining Bayesian neural networks and parametric profile fitting <https://arxiv.org/abs/2103.03257>`_

`Modelling high-resolution ALMA observations of strongly lensed dustystar forming galaxies detected by Herschel <https://arxiv.org/abs/2111.09680>`_

`Microlensing and the type Ia supernova iPTF16geu <https://arxiv.org/abs/2112.04524>`_

`Domain Adaptation for Simulation-Based Dark Matter Searches Using Strong Gravitational Lensing <https://arxiv.org/abs/2112.12121>`_

`On machine learning search for gravitational lenses <https://arxiv.org/abs/2104.01014>`_

**2022:**

`Automated galaxy-galaxy strong lens modelling: no lens left behind <https://arxiv.org/abs/2202.09201>`_

`Testing strong lensing subhalo detection with a cosmological simulation <https://arxiv.org/abs/2202.10191>`_